Resources:
- [In search of the perfect URL validation regex](https://mathiasbynens.be/demo/url-regex)
- [URL Regular Expression (Regex) for Validation and Parsing](https://urlregex.com/)
- [URL regex pattern](https://gist.github.com/dperini/729294)
- https://uibakery.io/regex-library/url
- https://stackoverflow.com/questions/3809401/what-is-a-good-regular-expression-to-match-a-url